==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/streamanalytics/kotlin/inputs/GetPrivateEndpointPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.streamanalytics.kotlin.inputs

import com.pulumi.azurenative.streamanalytics.inputs.GetPrivateEndpointPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property clusterName The name of the cluster.
 * @property privateEndpointName The name of the private endpoint.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class GetPrivateEndpointPlainArgs(
    public val clusterName: String,
    public val privateEndpointName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.streamanalytics.inputs.GetPrivateEndpointPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.streamanalytics.inputs.GetPrivateEndpointPlainArgs =
        com.pulumi.azurenative.streamanalytics.inputs.GetPrivateEndpointPlainArgs.builder()
            .clusterName(clusterName.let({ args0 -> args0 }))
            .privateEndpointName(privateEndpointName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetPrivateEndpointPlainArgs].
 */
@PulumiTagMarker
public class GetPrivateEndpointPlainArgsBuilder internal constructor() {
    private var clusterName: String? = null

    private var privateEndpointName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the cluster.
     */
    @JvmName("elcyydqsoiwdostb")
    public suspend fun clusterName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.clusterName = mapped
    }

    /**
     * @param value The name of the private endpoint.
     */
    @JvmName("rvealvoidbymxgmo")
    public suspend fun privateEndpointName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.privateEndpointName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("qpgtxpvmhdtpngnk")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetPrivateEndpointPlainArgs = GetPrivateEndpointPlainArgs(
        clusterName = clusterName ?: throw PulumiNullFieldException("clusterName"),
        privateEndpointName = privateEndpointName ?: throw PulumiNullFieldException("privateEndpointName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/streamanalytics/kotlin/inputs/GetPrivateEndpointPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.streamanalytics.kotlin.inputs

import com.pulumi.azurenative.streamanalytics.inputs.GetPrivateEndpointPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property clusterName The name of the cluster.
 * @property privateEndpointName The name of the private endpoint.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class GetPrivateEndpointPlainArgs(
    public val clusterName: String,
    public val privateEndpointName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.streamanalytics.inputs.GetPrivateEndpointPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.streamanalytics.inputs.GetPrivateEndpointPlainArgs =
        com.pulumi.azurenative.streamanalytics.inputs.GetPrivateEndpointPlainArgs.builder()
            .clusterName(clusterName.let({ args0 -> args0 }))
            .privateEndpointName(privateEndpointName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetPrivateEndpointPlainArgs].
 */
@PulumiTagMarker
public class GetPrivateEndpointPlainArgsBuilder internal constructor() {
    private var clusterName: String? = null

    private var privateEndpointName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the cluster.
     */
    @JvmName("xrngxshgkhjekwkn")
    public suspend fun clusterName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.clusterName = mapped
    }

    /**
     * @param value The name of the private endpoint.
     */
    @JvmName("ecfssgeqaagvkmkf")
    public suspend fun privateEndpointName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.privateEndpointName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("cmbnhocwoixywefy")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetPrivateEndpointPlainArgs = GetPrivateEndpointPlainArgs(
        clusterName = clusterName ?: throw PulumiNullFieldException("clusterName"),
        privateEndpointName = privateEndpointName ?: throw PulumiNullFieldException("privateEndpointName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}
